@@ -32,6 +32,17 @@ use vars qw(@ISA @EXPORT_OK);
 
 our @EXPORT_OK = qw(weak_set set);
 
+=head1 CONSTRUCTORS
+
+=over
+
+=item new
+
+This class method is exactly the same as C<Set::Object-E<gt>new>,
+except that it returns a weak set.
+
+=cut
+
 sub new {
     my $class = shift;
     my $self = $class->SUPER::new();
@@ -40,18 +51,43 @@ sub new {
     $self;
 }
 
+=item weak_set( ... )
+
+This optionally exported B<function> is a shortcut for saying
+C<Set::Object::Weak-E<gt>new(...)>.
+
+=cut
+
+
 sub weak_set {
     __PACKAGE__->new(@_);
 }
 
+=item set( ... )
+
+This method is exported so that if you see:
+
+ use Set::Object qw(set);
+
+You can turn it into using weak sets lexically with:
+
+ use Set::Object::Weak qw(set);
+
+Set::Object 1.19 had a bug in this method that meant that it would not
+add the passed members into it.
+
+=cut
+
 sub set {
-    __PACKAGE__->new();
+    __PACKAGE__->new(@_);
 }
 
 1;
 
 __END__
 
+=back
+
 =head1 SEE ALSO
 
 L<Set::Object>
